import schedule
import time
import json
import os
import sys

from .x import joke
from .AtlasI2C import AtlasI2C

storage_path_ph_long = "/var/www/raspberry_reactjs/logs/ph"
storage_path_ph_short = "/var/www/raspberry_reactjs/logs/ph_short"
storage_path_pump = "/var/www/raspberry_reactjs/logs/pump"
storage_path_pump_run = "/var/www/raspberry_reactjs/logs/pump_run"

run = True
runPump = 0
pumpAcid = False

ph = AtlasI2C()   # creates the I2C port object, specify the address or bus if necessary
ph.set_i2c_address(99)
ph.set_is_sensor(True)

pump = AtlasI2C()   # creates the I2C port object, specify the address or bus if necessary
pump.set_i2c_address(103)
pump.set_is_sensor(False)

def Log(storage, xVal, limit=-9):
  storage_today = storage + time.strftime("%Y-%m-%d") + ".json"
  storage_web = storage + ".json"
  
  data = None
  if os.path.exists(storage_today):
    with open(storage_today,'r') as f:
      try:
        data = json.load(f)
      except Exception as e:
        print("got %s on json.load()" % e)

  if data is None:
    print('Create new dataset')
    data = [ ]

  xTime = time.strftime("%Y-%m-%d %H:%M:%S")
  data.append({'time': xTime, 'value': xVal})

  if(limit>0):
    data = data[-limit:]

  with open(storage_today, 'w') as outfile:
    json.dump(data, outfile)
  
  with open(storage_web, 'w') as outfile:
    json.dump(data, outfile)

  return xTime

def PHLong():
  global runPump
  xVal = ph.query("R")

  if xVal > 6.0:
    runPump = runPump + 1
  elif runPump and xVal>5.6 and xVal < 5.9:
    runPump = 0
  elif xVal < 5.5:
    runPump = runPump - 1

  Log(storage_path_ph_long, xVal)
  Log(storage_path_pump_run, runPump)

def PHShort():
  xVal = ph.query("R")
  xTime = Log(storage_path_ph_short, xVal, 720)

  print("%s: pH %s" % (xTime, xVal))

def PumpLong():
  data = None
  pumpVal = 0
  print("PUMP VALUE: %s" % runPump)
  
  if runPump > 2:
    print("PUMP ACID!!")
    phVal = ph.query("R")
    if pumpAcid:
      if phVal>6.5:
        pumpVal = 5
      elif phVal>6.25:
        pumpVal = 5
      elif phVal>6.1:
        pumpVal = 2
      elif phVal>6.0:
        pumpVal = 1
      else:
        pumpVal = 0.5
  
  if runPump < -2:
    print("PUMP BASE!!")
    phVal = ph.query("R")
    if !pumpAcid:
      if phVal<5.0:
        pumpVal = 5
      elif phVal<5.25:
        pumpVal = 5
      elif phVal<5.4:
        pumpVal = 2
      elif phVal<5.5:
        pumpVal = 1
      else:
        pumpVal = 0.5
  
  if pumpVal > 0:
    print("PUMPING: %s" % pumpVal)
    print(pump.query("D,"+str(pumpVal)))
    Log(storage_path_pump,pumpVal)
    
def Goodbye():
  global run
  print("Goodbye")
  run = False


def main():
  print("Hello")
  
  schedule.every(5).seconds.do(PHShort)
  schedule.every(1).minutes.do(PHLong)
  schedule.every(30).minutes.do(PumpLong)
  schedule.every().day.at("23:55").do(Goodbye)
  
  try:
    while run:
      schedule.run_pending()
      time.sleep(1)
  except KeyboardInterrupt:     # catches the ctrl-c command, which breaks the loop above
    print("Continuous polling stopped")

if __name__ == '__main__':
  main()







#!/usr/bin/python

import io         # used to create file streams
import fcntl      # used to access I2C parameters like addresses

import time       # used for sleep delay and timestamps
import string     # helps parse strings


class AtlasI2C:
  long_timeout = 1.5           # the timeout needed to query readings and calibrations
  short_timeout = .5           # timeout for regular commands
  default_bus = 1           # the default bus for I2C on the newer Raspberry Pis, certain older boards use bus 0
  default_address = 99       # the default address for the sensor
  current_addr = default_address
  is_sensor = True

  def __init__(self, address=default_address, bus=default_bus):
    # open two file streams, one for reading and one for writing
    # the specific I2C channel is selected with bus
    # it is usually 1, except for older revisions where its 0
    # wb and rb indicate binary read and write
    self.file_read = io.open("/dev/i2c-"+str(bus), "rb", buffering=0)
    self.file_write = io.open("/dev/i2c-"+str(bus), "wb", buffering=0)

    # initializes I2C to either a user specified or default address
    self.set_i2c_address(address)
    self.set_is_sensor(True)

  def set_i2c_address(self, addr):
    # set the I2C communications to the slave specified by the address
    # The commands for I2C dev using the ioctl functions are specified in
    # the i2c-dev.h file from i2c-tools
    I2C_SLAVE = 0x703
    fcntl.ioctl(self.file_read, I2C_SLAVE, addr)
    fcntl.ioctl(self.file_write, I2C_SLAVE, addr)
    self.current_addr = addr
  
  def set_is_sensor(self, sens):
    self.is_sensor = sens

  def write(self, cmd):
    # appends the null character and sends the string over I2C
    cmd += "\00"
    cmd = cmd.encode()
    self.file_write.write(cmd)

  def read(self, num_of_bytes=31):
    # reads a specified number of bytes from I2C, then parses and displays the result
    res = self.file_read.read(num_of_bytes)         # read from the board
    response = list(filter(lambda x: x != '\x00', res))     # remove the null characters to get the response
    if response[0] == 1:             # if the response isn't an error
      # change MSB to 0 for all received characters except the first and get a list of characters
      char_list = map(lambda x: chr(x & ~0x80), list(response[1:]))
      # NOTE: having to change the MSB to 0 is a glitch in the raspberry pi, and you shouldn't have to do this!
      retval = ''.join(char_list).replace('\u0000','')
      if self.is_sensor:
        retval = float(retval)
      return retval      # convert the char list to a string and returns it
    else:
      return "Error " + str(response[0])

  def query(self, string):
    # write a command to the board, wait the correct timeout, and read the response
    self.write(string)

    # the read and calibration commands require a longer timeout
    if((string.upper().startswith("R")) or
      (string.upper().startswith("CAL"))):
      time.sleep(self.long_timeout)
    elif string.upper().startswith("SLEEP"):
      return "sleep mode"
    else:
      time.sleep(self.short_timeout)

    return self.read()

  def close(self):
    self.file_read.close()
    self.file_write.close()

  def list_i2c_devices(self):
    prev_addr = self.current_addr # save the current address so we can restore it after
    i2c_devices = []
    for i in range (0,128):
      try:
        self.set_i2c_address(i)
        self.read()
        i2c_devices.append(i)
      except IOError:
        pass
    self.set_i2c_address(prev_addr) # restore the address we were using
    return i2c_devices




import os, sys
sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))

from .x import joke

def main():
  print('foo = ', 1)
  print(joke())

if __name__ == '__main__':
  main()



import setuptools

def readme():
  '''Get long description from readme file'''
  with open('README.md') as f:
    return f.read()


def version():
  '''Get version from version file'''
  with open('VERSION') as f:
    return f.read().strip()

setuptools.setup(name='pihy',
      version=version(),
      entry_points={
      'console_scripts': [
                         'pihy = pihy.__main__:main'
                          ]
                 },
      description='The funniest joke in the world',
      long_description=readme(),
      url='http://github.com/raubreywhite/pihy',
      author='Richard',
      author_email='w@rwhite.no',
      license='MIT',
      packages=['pihy'],
      install_requires=[
                       'schedule',
                       ],
      zip_safe=False)
